@@ -56,11 +56,19 @@ class nqdm(tqdm.tqdm):
         self.depth = depth
 
         # if order has an inconsistent length, then set order to first
+
         if type(order) == list:
             if len(order) != len(args):
                 order = "first"
+
+        if order == "first":
+            order = list(range(len(args)))
+        if order == "last":
+            order = list(range(len(args)-1, -1, -1))
             
         self.order = order
+        map_order = sorted(zip(order, range(len(order))))
+        self.reverse_order = list(map(lambda kv : kv[1], map_order))
 
         self.enum = enum
 
@@ -83,31 +91,6 @@ class nqdm(tqdm.tqdm):
         # self.delay is set to 0
         self.delay = 0
 
-    def __order__(self, data):
-        """
-        Reorders the arguments
-        Parameters
-        ----------
-        data : list
-
-            List of arguments to be reordered
-        
-        Returns
-        ----------
-        sorted_values : list
-        
-            Reordered list of arguments
-        """
-        if self.order in ["first", "last"]:
-            if self.order == "last":
-                data = data[::-1]
-
-        else: 
-            data = [data[order_i] for order_i in self.order]
-        
-        return data
-    
-
     def __iter__(self):
         if self.disable:
             return self.values
@@ -168,7 +151,6 @@ class nqdm(tqdm.tqdm):
 
         is_range = are(range)
         is_string = are(str)
-        is_integer = are(int)
 
         is_sortable, has_keys, has_items, is_constant = False, False, False, False
         if has_dict:
@@ -191,7 +173,7 @@ class nqdm(tqdm.tqdm):
                 result = dict(y_i), "dict"
         
             else:
-                result = y_i, "int" if is_integer else "float"
+                result = int(y_i), "int"
         
         else:
             result = list(y_i) if is_countable else y_i, y_type
@@ -204,10 +186,7 @@ class nqdm(tqdm.tqdm):
         
         Parameters
         ----------
-        *args 
-        
-            Unpacked list of arguments of any iterable object type or int/float
-        
+       
         Returns
         ----------
         product : int
@@ -304,10 +283,6 @@ class nqdm(tqdm.tqdm):
         
             The current offset of the main progress bar
         
-        *args : list
-        
-            Unpacked list of arguments containing iterable objects or int/float variables
-        
         Returns
         ----------
         elems : list
@@ -318,7 +293,7 @@ class nqdm(tqdm.tqdm):
 
         elems = []
 
-        args = self.__order__(self.arguments)
+        args = [self.arguments[order_i] for order_i in self.order]
 
         for i in range(len(args)):
             data, typ = self.__convert__(args[i])
@@ -341,10 +316,58 @@ class nqdm(tqdm.tqdm):
             
             elems.append(data)
 
-        elems = elems[0] if len(elems) == 1 else self.__order__(elems)
+        elems = [elems[order_i] for order_i in self.reverse_order]
+        if len(elems) == 1 :
+            elems = elems[0] 
+
         if self.enum:
             elems = (point, elems)
 
         return elems
 
-    
\ No newline at end of file
+if __name__ == '__main__':
+    import numpy as np
+    import pandas as pd
+    from time import time
+
+    arg1 = {k: v for k,v in zip(list("abcde"), list("fghij"))}
+    arg2 = [v**2 for v in range(10)]
+    arg3 = 4.0
+
+    start = time()
+    for data in nqdm(arg1):
+        print(data)
+    print(time() - start)
+
+    start = time()
+    for data in nqdm(arg1, arg2, arg3):
+        print(data)
+    print(time() - start)
+
+    arg1_deep = np.arange(80000).reshape(200, 20, 20)
+    arg2_deep = {str(i): {k+str(i): v+str(i) for k,v in zip(list("abcde"), list("fghij"))} for i in range(20)}  
+
+    start = time()
+    for data in nqdm(arg1_deep, depth=0):
+        pass
+    print(time() - start)
+
+    start = time()
+    for data in nqdm(arg1_deep, depth=1):
+        pass
+    print(time() - start)
+
+    start = time()
+    for data in nqdm(arg1_deep, depth=2):
+        pass
+    print(time() - start)
+
+    start = time()
+    for data in nqdm(arg2_deep, depth=0):
+        pass
+    print(time() - start)
+
+    start = time()
+    for data in nqdm(arg2_deep, depth=1):
+        pass
+    print(time() - start)
